<?php
// Import framework stuff
use CoreFramework\Configuration\FrameworkConfiguration;
use CoreFramework\Connection\Database\DatabaseConnection;
use CoreFramework\Object\BaseFrameworkSystem;
use CoreFramework\Middleware\Debug\DebugMiddleware;

/**
 * Initializes the database layer
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 * @deprecated
 * @todo		Minimize these includes
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

// Initialize database layer
$databaseInstance = NULL;

// Generate FQFN for the database layer
$fqfn = FrameworkConfiguration::getSelfInstance()->getConfigEntry('base_path') . 'inc/database/lib-' . FrameworkConfiguration::getSelfInstance()->getConfigEntry('db_type') . '.php';

// Load the database layer include
if (BaseFrameworkSystem::isReadableFile($fqfn)) {
	// Load the layer
	require($fqfn);
} else {
	// Layer is missing!
	ApplicationEntryPoint::app_exit(sprintf('[Main:] Database layer is missing! (%s) -&gt; R.I.P.',
		FrameworkConfiguration::getSelfInstance()->getConfigEntry('db_type')
	));
}

// Clean it up
unset($fqfn);

// Prepare database instance
$connectionInstance = DatabaseConnection::createDatabaseConnection(DebugMiddleware::getSelfInstance(), $databaseInstance);

// Is the app variable there and valid?
// @TODO Rewrite this
if (is_object($app)) {
	$app->setDatabaseInstance($connectionInstance);
} // END - if
