<?php
// Own namespace
namespace CoreFramework\Handler\Protocol;

/**
 * An interface for protocol handlers
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface HandleableProtocol extends Handleable {
	/**
	 * Getter for port number to satify HandleableProtocol
	 *
	 * @return	$port	The port number
	 */
	function getPort ();

	/**
	 * Getter for protocol name
	 *
	 * @return	$protocol	Name of used protocol
	 */
	function getProtocolName ();

	/**
	 * Validates given 'recipient' if it is a valid UNL. This means that the UNL
	 * can be parsed by the protocol handler.
	 *
	 * @param	$packageData	Valid raw package data
	 * @return	$isValid		Whether the UNL can be validated
	 */
	function isValidUniversalNodeLocatorByPackageData (array $packageData);

	/**
	 * If the found UNL (address) matches own external or internal address
	 *
	 * @param	$unl		UNL to test
	 * @return	$ifMatches	Whether the found UNL matches own addresss
	 */
	function isOwnAddress ($unl);

}
